/*!
 *  Lang.js for Laravel localization in JavaScript.
 *
 *  @version 1.1.10
 *  @license MIT https://github.com/rmariuzzo/Lang.js/blob/master/LICENSE
 *  @site    https://github.com/rmariuzzo/Lang.js
 *  @author  Rubens Mariuzzo <rubens@mariuzzo.com>
 */
(function(root,factory){"use strict";if(typeof define==="function"&&define.amd){define([],factory)}else if(typeof exports==="object"){module.exports=factory()}else{root.Lang=factory()}})(this,function(){"use strict";function inferLocale(){if(typeof document!=="undefined"&&document.documentElement){return document.documentElement.lang}}function convertNumber(str){if(str==="-Inf"){return-Infinity}else if(str==="+Inf"||str==="Inf"||str==="*"){return Infinity}return parseInt(str,10)}var intervalRegexp=/^({\s*(\-?\d+(\.\d+)?[\s*,\s*\-?\d+(\.\d+)?]*)\s*})|([\[\]])\s*(-Inf|\*|\-?\d+(\.\d+)?)\s*,\s*(\+?Inf|\*|\-?\d+(\.\d+)?)\s*([\[\]])$/;var anyIntervalRegexp=/({\s*(\-?\d+(\.\d+)?[\s*,\s*\-?\d+(\.\d+)?]*)\s*})|([\[\]])\s*(-Inf|\*|\-?\d+(\.\d+)?)\s*,\s*(\+?Inf|\*|\-?\d+(\.\d+)?)\s*([\[\]])/;var defaults={locale:"en"};var Lang=function(options){options=options||{};this.locale=options.locale||inferLocale()||defaults.locale;this.fallback=options.fallback;this.messages=options.messages};Lang.prototype.setMessages=function(messages){this.messages=messages};Lang.prototype.getLocale=function(){return this.locale||this.fallback};Lang.prototype.setLocale=function(locale){this.locale=locale};Lang.prototype.getFallback=function(){return this.fallback};Lang.prototype.setFallback=function(fallback){this.fallback=fallback};Lang.prototype.has=function(key,locale){if(typeof key!=="string"||!this.messages){return false}return this._getMessage(key,locale)!==null};Lang.prototype.get=function(key,replacements,locale){if(!this.has(key,locale)){return key}var message=this._getMessage(key,locale);if(message===null){return key}if(replacements){message=this._applyReplacements(message,replacements)}return message};Lang.prototype.trans=function(key,replacements){return this.get(key,replacements)};Lang.prototype.choice=function(key,number,replacements,locale){replacements=typeof replacements!=="undefined"?replacements:{};replacements.count=number;var message=this.get(key,replacements,locale);if(message===null||message===undefined){return message}var messageParts=message.split("|");var explicitRules=[];for(var i=0;i<messageParts.length;i++){messageParts[i]=messageParts[i].trim();if(anyIntervalRegexp.test(messageParts[i])){var messageSpaceSplit=messageParts[i].split(/\s/);explicitRules.push(messageSpaceSplit.shift());messageParts[i]=messageSpaceSplit.join(" ")}}if(messageParts.length===1){return message}for(var j=0;j<explicitRules.length;j++){if(this._testInterval(number,explicitRules[j])){return messageParts[j]}}var pluralForm=this._getPluralForm(number);return messageParts[pluralForm]};Lang.prototype.transChoice=function(key,count,replacements){return this.choice(key,count,replacements)};Lang.prototype._parseKey=function(key,locale){if(typeof key!=="string"||typeof locale!=="string"){return null}var segments=key.split(".");var source=segments[0].replace(/\//g,".");return{source:locale+"."+source,sourceFallback:this.getFallback()+"."+source,entries:segments.slice(1)}};Lang.prototype._getMessage=function(key,locale){locale=locale||this.getLocale();key=this._parseKey(key,locale);if(this.messages[key.source]===undefined&&this.messages[key.sourceFallback]===undefined){return null}var message=this.messages[key.source];var entries=key.entries.slice();var subKey="";while(entries.length&&message!==undefined){var subKey=!subKey?entries.shift():subKey.concat(".",entries.shift());if(message[subKey]!==undefined){message=message[subKey];subKey=""}}if(typeof message!=="string"&&this.messages[key.sourceFallback]){message=this.messages[key.sourceFallback];entries=key.entries.slice();subKey="";while(entries.length&&message!==undefined){var subKey=!subKey?entries.shift():subKey.concat(".",entries.shift());if(message[subKey]){message=message[subKey];subKey=""}}}if(typeof message!=="string"){return null}return message};Lang.prototype._findMessageInTree=function(pathSegments,tree){while(pathSegments.length&&tree!==undefined){var dottedKey=pathSegments.join(".");if(tree[dottedKey]){tree=tree[dottedKey];break}tree=tree[pathSegments.shift()]}return tree};Lang.prototype._applyReplacements=function(message,replacements){for(var replace in replacements){message=message.replace(new RegExp(":"+replace,"gi"),function(match){var value=replacements[replace];var allCaps=match===match.toUpperCase();if(allCaps){return value.toUpperCase()}var firstCap=match===match.replace(/\w/i,function(letter){return letter.toUpperCase()});if(firstCap){return value.charAt(0).toUpperCase()+value.slice(1)}return value})}return message};Lang.prototype._testInterval=function(count,interval){if(typeof interval!=="string"){throw"Invalid interval: should be a string."}interval=interval.trim();var matches=interval.match(intervalRegexp);if(!matches){throw"Invalid interval: "+interval}if(matches[2]){var items=matches[2].split(",");for(var i=0;i<items.length;i++){if(parseInt(items[i],10)===count){return true}}}else{matches=matches.filter(function(match){return!!match});var leftDelimiter=matches[1];var leftNumber=convertNumber(matches[2]);if(leftNumber===Infinity){leftNumber=-Infinity}var rightNumber=convertNumber(matches[3]);var rightDelimiter=matches[4];return(leftDelimiter==="["?count>=leftNumber:count>leftNumber)&&(rightDelimiter==="]"?count<=rightNumber:count<rightNumber)}return false};Lang.prototype._getPluralForm=function(count){switch(this.locale){case"az":case"bo":case"dz":case"id":case"ja":case"jv":case"ka":case"km":case"kn":case"ko":case"ms":case"th":case"tr":case"vi":case"zh":return 0;case"af":case"bn":case"bg":case"ca":case"da":case"de":case"el":case"en":case"eo":case"es":case"et":case"eu":case"fa":case"fi":case"fo":case"fur":case"fy":case"gl":case"gu":case"ha":case"he":case"hu":case"is":case"it":case"ku":case"lb":case"ml":case"mn":case"mr":case"nah":case"nb":case"ne":case"nl":case"nn":case"no":case"om":case"or":case"pa":case"pap":case"ps":case"pt":case"so":case"sq":case"sv":case"sw":case"ta":case"te":case"tk":case"ur":case"zu":return count==1?0:1;case"am":case"bh":case"fil":case"fr":case"gun":case"hi":case"hy":case"ln":case"mg":case"nso":case"xbr":case"ti":case"wa":return count===0||count===1?0:1;case"be":case"bs":case"hr":case"ru":case"sr":case"uk":return count%10==1&&count%100!=11?0:count%10>=2&&count%10<=4&&(count%100<10||count%100>=20)?1:2;case"cs":case"sk":return count==1?0:count>=2&&count<=4?1:2;case"ga":return count==1?0:count==2?1:2;case"lt":return count%10==1&&count%100!=11?0:count%10>=2&&(count%100<10||count%100>=20)?1:2;case"sl":return count%100==1?0:count%100==2?1:count%100==3||count%100==4?2:3;case"mk":return count%10==1?0:1;case"mt":return count==1?0:count===0||count%100>1&&count%100<11?1:count%100>10&&count%100<20?2:3;case"lv":return count===0?0:count%10==1&&count%100!=11?1:2;case"pl":return count==1?0:count%10>=2&&count%10<=4&&(count%100<12||count%100>14)?1:2;case"cy":return count==1?0:count==2?1:count==8||count==11?2:3;case"ro":return count==1?0:count===0||count%100>0&&count%100<20?1:2;case"ar":return count===0?0:count==1?1:count==2?2:count%100>=3&&count%100<=10?3:count%100>=11&&count%100<=99?4:5;default:return 0}};return Lang});

(function () {
    Lang = new Lang();
    Lang.setMessages({"ar.js":{"add_location":"\u0625\u0636\u0627\u0641\u0629 \u0645\u0648\u0642\u0639","admin":"\u0627\u0644\u0645\u0633\u0624\u0648\u0644","apply":"\u062a\u0642\u062f\u064a\u0645 \u0627\u0644\u0637\u0644\u0628","apr":"\u0623\u0628\u0631\u064a\u0644","aug":"\u0623\u063a\u0633\u0637\u0633","cancel":"\u0625\u0644\u063a\u0627\u0621","cancel_reason_cannot_space":"\u0644\u0627 \u064a\u0645\u0643\u0646 \u0623\u0646 \u064a\u0643\u0648\u0646 \u0633\u0628\u0628 \u0627\u0644\u0625\u0644\u063a\u0627\u0621 \u0645\u062c\u0631\u062f \u0645\u0633\u0627\u0641\u0627\u062a.","cancel_reason_required":"\u062d\u0642\u0644 \u0633\u0628\u0628 \u0627\u0644\u0625\u0644\u063a\u0627\u0621 \u0645\u0637\u0644\u0648\u0628.","cancel_scheduled":"\u0644\u0627 \u064a\u0645\u0643\u0646 \u0623\u0646 \u064a\u0643\u0648\u0646 \u0633\u0628\u0628 \u0627\u0644\u0625\u0644\u063a\u0627\u0621 \u0645\u062c\u0631\u062f \u0645\u0633\u0627\u0641\u0627\u062a.","captcha_key":"\u062d\u0642\u0644 \u0645\u0641\u062a\u0627\u062d Google Captcha \u0645\u0637\u0644\u0648\u0628.","captcha_secret":"\u062d\u0642\u0644 Google Captcha Secret \u0645\u0637\u0644\u0648\u0628.","choose_plan":"\u0627\u062e\u062a\u0631 \u0627\u0644\u062e\u0637\u0629","contact_number_is_invalid_number":"\u0631\u0642\u0645 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d","copied":"\u062a\u0645 \u0627\u0644\u0646\u0633\u062e","copy_link":"\u0646\u0633\u062e \u0627\u0644\u0631\u0627\u0628\u0637","currency":"\u0627\u0644\u0639\u0645\u0644\u0629","dec":"\u062f\u064a\u0633\u0645\u0628\u0631","default_schedule":"\u0644\u0627 \u064a\u0645\u0643\u0646 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062c\u062f\u0648\u0644 \u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a.","delete":"\u062d\u0630\u0641!","description":"\u0627\u0644\u0648\u0635\u0641","description_required":"\u0627\u0644\u0648\u0635\u0641 \u0645\u0637\u0644\u0648\u0628.","desig_required":"\u062d\u0642\u0644 \u0627\u0644\u062a\u0635\u0645\u064a\u0645 \u0645\u0637\u0644\u0648\u0628.","email_verified_successfully":"\u062a\u0645 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0628\u0646\u062c\u0627\u062d.","enquiry":"\u0627\u0633\u062a\u0641\u0633\u0627\u0631","enter_google_api":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0645\u0641\u062a\u0627\u062d Google Place API.","enter_valid_facebook_url":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0631\u0627\u0628\u0637 Facebook \u0635\u0627\u0644\u062d","enter_valid_instagram_url":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0631\u0627\u0628\u0637 Instagram \u0635\u0627\u0644\u062d","enter_valid_twitter_url":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0631\u0627\u0628\u0637 Twitter \u0635\u0627\u0644\u062d","event":"\u062d\u062f\u062b","faq":"\u0627\u0644\u0623\u0633\u0626\u0644\u0629 \u0627\u0644\u0634\u0627\u0626\u0639\u0629","feb":"\u0641\u0628\u0631\u0627\u064a\u0631","fri":"\u0627\u0644\u062c\u0645\u0639\u0629","from":"\u0645\u0646","front_band":"\u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0627\u0644\u0623\u0645\u0627\u0645\u064a\u0629","front_testimonial":"\u0627\u0644\u0634\u0647\u0627\u062f\u0629 \u0627\u0644\u0623\u0645\u0627\u0645\u064a\u0629","invalid_country_code":"\u0631\u0645\u0632 \u0627\u0644\u062f\u0648\u0644\u0629 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d","invalid_number":"\u0631\u0642\u0645 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d","jan":"\u064a\u0646\u0627\u064a\u0631","jul":"\u064a\u0648\u0644\u064a\u0648","jun":"\u064a\u0648\u0646\u064a\u0648","linked_copy_successfully":"\u062a\u0645 \u0627\u0644\u0646\u0633\u062e \u0628\u0646\u062c\u0627\u062d.","location":"\u062d\u0642\u0644 \u0627\u0633\u0645 \u0627\u0644\u0645\u0648\u0642\u0639 \u0645\u0637\u0644\u0648\u0628.","location_white":"\u062d\u0642\u0644 \u0627\u0633\u0645 \u0627\u0644\u0645\u0648\u0642\u0639 \u0645\u0637\u0644\u0648\u0628.","mar":"\u0645\u0627\u0631\u0633","mon":"\u0627\u0644\u0627\u062b\u0646\u064a\u0646","name_required":"\u062d\u0642\u0644 \u0627\u0644\u0627\u0633\u0645 \u0645\u0637\u0644\u0648\u0628.","no":"\u0644\u0627","nov":"\u0646\u0648\u0641\u0645\u0628\u0631","oct":"\u0623\u0643\u062a\u0648\u0628\u0631","ok":"\u062d\u0633\u0646\u0627","paypal_client":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0645\u0639\u0631\u0641 \u0639\u0645\u064a\u0644 Paypal.","paypal_mode":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0648\u0636\u0639 Paypal.","paypal_secret":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0633\u0631 Paypal.","paystack_key":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0645\u0641\u062a\u0627\u062d Paystack.","paystack_secret":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0633\u0631 Paystack.","personal_experience":"\u0627\u0644\u062a\u062c\u0631\u0628\u0629 \u0627\u0644\u0634\u062e\u0635\u064a\u0629","phone":"\u062d\u0642\u0644 \u0627\u0644\u0647\u0627\u062a\u0641 \u0645\u0637\u0644\u0648\u0628.","phone_required":"\u062d\u0642\u0644 \u0631\u0642\u0645 \u0627\u0644\u0647\u0627\u062a\u0641 \u0645\u0637\u0644\u0648\u0628.","privacy_policy":"\u0633\u064a\u0627\u0633\u0629 \u0627\u0644\u062e\u0635\u0648\u0635\u064a\u0629 \u0645\u0637\u0644\u0648\u0628\u0629.","profile_size":"\u064a\u062c\u0628 \u0623\u0646 \u064a\u0643\u0648\u0646 \u062d\u062c\u0645 \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a \u0623\u0642\u0644 \u0645\u0646 2 \u0645\u064a\u062c\u0627\u0628\u0627\u064a\u062a.","razorpay_key":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0645\u0641\u062a\u0627\u062d RazorPay \u0627\u0644\u062e\u0627\u0635 \u0628\u0643","razorpay_secret":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0633\u0631 RazorPay \u0627\u0644\u062e\u0627\u0635 \u0628\u0643","sat":"\u0627\u0644\u0633\u0628\u062a","schedule":"\u0627\u0644\u062c\u062f\u0648\u0644","schedule_name":"\u062d\u0642\u0644 \u0627\u0633\u0645 \u0627\u0644\u062c\u062f\u0648\u0644 \u0645\u0637\u0644\u0648\u0628.","select_calender":"\u064a\u0631\u062c\u0649 \u0627\u062e\u062a\u064a\u0627\u0631 \u062a\u0642\u0648\u064a\u0645.","select_event_type":"\u0627\u062e\u062a\u0631 \u0646\u0648\u0639 \u0627\u0644\u062d\u062f\u062b","select_personal_experience":"\u062d\u062f\u062f \u0627\u0644\u062a\u062c\u0631\u0628\u0629 \u0627\u0644\u0634\u062e\u0635\u064a\u0629","select_status":"\u0627\u062e\u062a\u0631 \u0627\u0644\u062d\u0627\u0644\u0629","select_subscription_plans":"\u062d\u062f\u062f \u062e\u0637\u0637 \u0627\u0644\u0627\u0634\u062a\u0631\u0627\u0643","sep":"\u0633\u0628\u062a\u0645\u0628\u0631","short_description":"\u062d\u0642\u0644 \u0627\u0644\u0648\u0635\u0641 \u0627\u0644\u0642\u0635\u064a\u0631 \u0645\u0637\u0644\u0648\u0628.","slot_time":"\u062d\u0642\u0644 \u0648\u0642\u062a \u0627\u0644\u0641\u062a\u062d\u0629 \u0645\u0637\u0644\u0648\u0628.","something_went_wrong":"\u062d\u062f\u062b \u062e\u0637\u0623!","stripe_key":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0645\u0641\u062a\u0627\u062d Stripe.","stripe_secret":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0633\u0631 Stripe.","subscriber":"\u0645\u0634\u062a\u0631\u0643","subscription_plan":"\u062e\u0637\u0629 \u0627\u0644\u0627\u0634\u062a\u0631\u0627\u0643","subscription_plans":"\u062e\u0637\u0637 \u0627\u0644\u0627\u0634\u062a\u0631\u0627\u0643","successful":"\u0646\u0627\u062c\u062d","sun":"\u0627\u0644\u0623\u062d\u062f","sure_delete":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0627","terms_cond":"\u0627\u0644\u0634\u0631\u0648\u0637 \u0648\u0627\u0644\u0623\u062d\u0643\u0627\u0645","terms_condition":"\u0627\u0644\u0634\u0631\u0648\u0637 \u0648\u0627\u0644\u0623\u062d\u0643\u0627\u0645 \u0645\u0637\u0644\u0648\u0628\u0629.","this_event_can_not_be_deleted":"\u0644\u0627 \u064a\u0645\u0643\u0646 \u062d\u0630\u0641 \u0647\u0630\u0627 \u0627\u0644\u062d\u062f\u062b","thu":"\u0627\u0644\u062e\u0645\u064a\u0633","to":"\u0625\u0644\u0649","too_long":"\u0637\u0648\u064a\u0644 \u062c\u062f\u0627\u064b","too_short":"\u0642\u0635\u064a\u0631 \u062c\u062f\u0627\u064b","tue":"\u0627\u0644\u062b\u0644\u0627\u062b\u0627\u0621","user_details":"\u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645","wed":"\u0627\u0644\u0623\u0631\u0628\u0639\u0627\u0621","yes":"\u0646\u0639\u0645"},"de.js":{"add_location":"Ort hinzuf\u00fcgen","admin":"Administrator","apply":"Anwenden","apr":"Apr","aug":"Aug","cancel":"Abbrechen","cancel_reason_cannot_space":"Der Abbruchgrund darf nicht nur aus Leerzeichen bestehen.","cancel_reason_required":"Das Feld \u201eGrund des Abbruchs\u201c ist erforderlich.","cancel_scheduled":"Das Popup-Fenster \u201eGeplante Ereignisse abbrechen\u201c wird angezeigt","captcha_key":"Das Google Captcha-Schl\u00fcsselfeld ist erforderlich.","captcha_secret":"Das Feld \u201eGoogle Captcha Secret\u201c ist erforderlich.","choose_plan":"Plan ausw\u00e4hlen","contact_number_is_invalid_number":"Die Kontaktnummer ist keine g\u00fcltige Nummer","copied":"Kopiert","copy_link":"Link kopieren","currency":"W\u00e4hrung","dec":"Dez","default_schedule":"Standardzeitplan kann nicht aktualisiert werden.","delete":"L\u00f6schen!","description":"Beschreibung","description_required":"Die Beschreibung ist erforderlich.","desig_required":"Das Feld Bezeichnung ist erforderlich.","email_verified_successfully":"E-Mail erfolgreich verifiziert.","enquiry":"Anfrage","enter_google_api":"Bitte geben Sie den Google Place API-Schl\u00fcssel ein.","enter_valid_facebook_url":"Bitte geben Sie eine g\u00fcltige Facebook-URL ein","enter_valid_instagram_url":"Bitte geben Sie eine g\u00fcltige Instagram-URL ein","enter_valid_twitter_url":"Bitte geben Sie eine g\u00fcltige Twitter-URL ein","event":"Veranstaltung","faq":"FAQ","feb":"Feb","fri":"Fr","from":"Von","front_band":"Front Marke","front_testimonial":"Front Testimonial","invalid_country_code":"Ung\u00fcltiger L\u00e4ndercode","invalid_number":"Ung\u00fcltige Nummer","jan":"Jan","jul":"Jul","jun":"Jun","linked_copy_successfully":"Verkn\u00fcpfung erfolgreich kopiert.","location":"Der Ort Name ist erforderlich.","location_white":"Der Ort Name ist erforderlich.","mar":"M\u00e4r","mon":"Mo","name_required":"Der Name ist erforderlich.","no":"Nein","nov":"Nov","oct":"Okt","ok":"Ok","paypal_client":"Bitte geben Sie die Paypal Client ID ein.","paypal_mode":"Bitte geben Sie den Paypal-Modus ein.","paypal_secret":"Bitte geben Sie das Paypal Secret ein.","paystack_key":"Bitte geben Sie den Paystack-Schl\u00fcssel ein.","paystack_secret":"Bitte geben Sie Paystack Secret ein.","personal_experience":"Pers\u00f6nliche Erfahrung","phone":"Telefonnummer ist erforderlich.","phone_required":"Das Telefonnummernfeld ist erforderlich.","privacy_policy":"Die Datenschutzrichtlinie ist erforderlich.","profile_size":"Das Profil sollte kleiner als 2 MB sein.","razorpay_key":"Bitte geben Sie Ihren RazorPay-Schl\u00fcssel ein","razorpay_secret":"Bitte geben Sie Ihr RazorPay-Geheimnis ein","sat":"Sa","schedule":"Zeitplan","schedule_name":"Der Zeitplanname ist erforderlich.","select_calender":"Bitte w\u00e4hlen Sie einen Kalender aus.","select_event_type":"W\u00e4hlen Sie den Ereignistyp","select_personal_experience":"Pers\u00f6nliche Erfahrung ausw\u00e4hlen","select_status":"Status ausw\u00e4hlen","select_subscription_plans":"W\u00e4hlen Sie Abonnementpl\u00e4ne","sep":"Sep","short_description":"Das Feld Kurzbeschreibung ist erforderlich.","slot_time":"Die Slot-Zeit ist erforderlich.","something_went_wrong":"Etwas ist schief gelaufen!","stripe_key":"Bitte geben Sie den Stripe Key ein.","stripe_secret":"Bitte geben Sie das Stripe Secret ein.","subscriber":"Abonnent","subscription_plan":"Abonnementplan","subscription_plans":"Abonnementpl\u00e4ne","successful":"Erfolgreich","sun":"So","sure_delete":"M\u00f6chten Sie dies wirklich l\u00f6schen","terms_cond":"Nutzungsbedingungen","terms_condition":"Die Nutzungsbedingungen sind erforderlich.","this_event_can_not_be_deleted":"Diese Veranstaltung kann nicht gel\u00f6scht werden","thu":"Do","to":"Zu","too_long":"Zu lang","too_short":"Zu kurz","tue":"Di","user_details":"Benutzer","wed":"Mi","yes":"Ja"},"en.js":{"add_location":"Add Location","address_required":"The Address field is required.","admin":"Admin","apply":"Apply","apr":"Apr","aug":"Aug","cancel":"Cancel","cancel_reason_cannot_space":"Cancel reason cannot be just spaces.","cancel_reason_required":"Cancel reason field is required.","cancel_scheduled":"Cancel Scheduled Events pop up","captcha_key":"The Google Captcha key field is required.","captcha_secret":"The Google Captcha Secret field is required.","choose_plan":"Choose Plan","contact_number_is":"Contact number is","contact_number_is_invalid_number":"Contact number is invalid number","copied":"Copied","copy_link":"Copy Link","currency":"Currency","day_of_week":"Please select any days","dec":"Dec","default_schedule":"Default schedule can't be updated.","delete":"Delete !","description":"Description","description_1":"The description 1 field is required.","description_1_length":"The description 1 must not be greater than 122 characters.","description_2":"The description 2 field is required.","description_2_length":"The description 2 must not be greater than 122 characters.","description_3":"The description 3 field is required.","description_3_length":"The description 3 must not be greater than 122 characters.","description_required":"The Description is required.","desig_required":"The designation field is required.","domain_url":"The Domain URL field is required.","email_required":"The Email field is required.","email_verified_successfully":"Email Verified Successfully.","enquiry":"Enquiry","enter_google_api":"Please enter google place API key.","enter_valid_facebook_url":"Please enter a valid Facebook URL","enter_valid_instagram_url":"Please enter a valid Instagram URL","enter_valid_twitter_url":"Please enter a valid Twitter URL","event":"Event","faq":"FAQ","feb":"Feb","fri":"Fri","from":"From","from_time":"The From hour field is required.","front_band":"Front Brand","front_testimonial":"Front Testimonial","image_size":"Image size should be less than 2 MB.","invalid_country_code":"Invalid country code","invalid_number":"Invalid Number","jan":"Jan","jul":"Jul","jun":"Jun","linked_copy_successfully":"Linked Copied Successfully.","location":"Location name field is required.","location_white":"Location name field is required.","main_title":"The main title field is required.","mar":"Mar","mon":"Mon","name_required":"The name field is required.","no":"No","nov":"Nov","oct":"Oct","ok":"Ok","paypal_client":"Please enter Paypal Client ID.","paypal_mode":"Please enter Paypal Mode.","paypal_secret":"Please enter Paypal Secret.","paystack_key":"Please enter your paystack key","paystack_secret":"Please enter your paystack seceret","personal_experience":"Personal experience field is required.","phone":"Phone field is required.","phone_required":"The Contact field is required.","privacy_policy":"The Privacy Policy is required.","profile_size":"Profile size should be less than 2 MB.","razorpay_key":"Please enter your RazorPay key","razorpay_secret":"Please enter your RazorPay Secret","sat":"Sat","schedule":"Schedule","schedule_name":"Schedule name field is required.","select_calender":"Please select a calendar.","select_event_type":"Select Event Type","select_personal_experience":"Select Personal Experience","select_status":"Select Status","select_subscription_plans":"Select Subscription Plans","sep":"Sep","service_description_1":"The service description 1 field is required.","service_description_1_length":"The description 1 must not be greater than 90 characters.","service_description_2":"The service description 2 field is required.","service_description_2_length":"The service description 2 must not be greater than 90 characters.","service_description_3":"The service description 3 field is required.","service_description_3_length":"The service description 3 must not be greater than 90 characters.","service_title_1":"The service title 1 field is required.","service_title_2":"The service title 2 field is required.","service_title_3":"The service title 3 field is required.","short_description":"The short description field is required.","slot_time":"Slot time field is required.","something_went_wrong":"Something went wrong!","stripe_key":"Please enter Stripe Key.","stripe_secret":"Please enter Stripe Secret.","subscriber":"Subscriber","subscription_plan":"Subscription Plan","subscription_plans":"Subscription Plans","subscription_status_changed_successfully":"Status updated successfully","successful":"Successful","sun":"Sun","sure_delete":"Are you sure want to delete this","terms_cond":"Terms & Conditions","terms_condition":"The Terms & Conditions is required.","this_event_can_not_be_deleted":"This event can't be deleted","thu":"Thu","timezone":"The Timezone field is required.","title_1":"The title 1 field is required.","title_2":"The title 2 field is required.","title_3":"The title 3 field is required.","title_required":"The Title field is required.","to":"To","to_time":"The To hour field is required.","too_long":"Too long","too_short":"Too short","tue":"Tue","user_details":"User","valid_file":"The attachment must be a file of type: jpg, png, jpeg, pdf","valid_file_size":"The maximum attachment size 10 mb allowed","wed":"Wed","yes":"Yes"},"es.js":{"add_location":"Agregar ubicaci\u00f3n","admin":"Administrador","apply":"Aplicar","apr":"Abr","aug":"Ago","cancel":"Cancelar","cancel_reason_cannot_space":"El motivo de la cancelaci\u00f3n no puede ser solo espacios.","cancel_reason_required":"El campo de motivo de cancelaci\u00f3n es obligatorio.","cancel_scheduled":"Cancelar eventos programados emergente","captcha_key":"El campo clave de Google Captcha es obligatorio.","captcha_secret":"El campo Secreto de Google Captcha es obligatorio.","choose_plan":"Elegir Plan","contact_number_is_invalid_number":"El n\u00famero de contacto es un n\u00famero inv\u00e1lido","copied":"Copiado","copy_link":"Copiar Enlace","currency":"Moneda","dec":"Dic","default_schedule":"No se puede actualizar el horario predeterminado.","delete":"\u00a1Eliminar!","description":"Descripci\u00f3n","description_required":"La descripci\u00f3n es obligatoria.","desig_required":"El campo del cargo es obligatorio.","email_verified_successfully":"Correo electr\u00f3nico verificado exitosamente.","enquiry":"Consulta","enter_google_api":"Ingrese la clave de API de Google Place, por favor.","enter_valid_facebook_url":"Ingrese una URL de Facebook v\u00e1lida, por favor","enter_valid_instagram_url":"Ingrese una URL de Instagram v\u00e1lida, por favor","enter_valid_twitter_url":"Ingrese una URL de Twitter v\u00e1lida, por favor","event":"Evento","faq":"Preguntas frecuentes","feb":"Feb","fri":"Vie","from":"Desde","front_band":"Marca Frontal","front_testimonial":"Testimonio Frontal","invalid_country_code":"C\u00f3digo de pa\u00eds inv\u00e1lido","invalid_number":"N\u00famero inv\u00e1lido","jan":"Ene","jul":"Jul","jun":"Jun","linked_copy_successfully":"Enlace copiado exitosamente.","location":"El campo del nombre de la ubicaci\u00f3n es obligatorio.","location_white":"El campo del nombre de la ubicaci\u00f3n es obligatorio.","mar":"Mar","mon":"Lun","name_required":"El campo del nombre es obligatorio.","no":"No","nov":"Nov","oct":"Oct","ok":"Ok","paypal_client":"Ingrese la ID de Cliente de Paypal, por favor.","paypal_mode":"Ingrese el Modo de Paypal, por favor.","paypal_secret":"Ingrese la clave secreta de Paypal, por favor.","paystack_key":"Ingrese la clave de Paystack.","paystack_secret":"Ingrese el secreto de Paystack.","personal_experience":"Experiencia Personal","phone":"El campo del n\u00famero de tel\u00e9fono es obligatorio.","phone_required":"El campo del n\u00famero de tel\u00e9fono es obligatorio.","privacy_policy":"La Pol\u00edtica de Privacidad es obligatoria.","profile_size":"El tama\u00f1o del perfil debe ser menor a 2 MB.","razorpay_key":"Por favor ingrese su clave RazorPay","razorpay_secret":"Por favor ingrese su secreto de RazorPay","sat":"S\u00e1b","schedule":"Horario","schedule_name":"El campo del nombre del horario es obligatorio.","select_calender":"Seleccione un calendario, por favor.","select_event_type":"Seleccionar Tipo de Evento","select_personal_experience":"Seleccionar Experiencia Personal","select_status":"Seleccionar Estado","select_subscription_plans":"Elija planes de suscripci\u00f3n","sep":"Sep","short_description":"El campo de la breve descripci\u00f3n es obligatorio.","slot_time":"El campo del tiempo de la ranura es obligatorio.","something_went_wrong":"\u00a1Algo sali\u00f3 mal!","stripe_key":"Ingrese la clave de Stripe, por favor.","stripe_secret":"Ingrese la clave secreta de Stripe, por favor.","subscriber":"Suscriptor","subscription_plan":"Plan de Suscripci\u00f3n","subscription_plans":"Planes de suscripci\u00f3n","successful":"Exitoso","sun":"Dom","sure_delete":"\u00bfEst\u00e1s seguro de que quieres eliminar esto?","terms_cond":"T\u00e9rminos y Condiciones","terms_condition":"Los T\u00e9rminos y Condiciones son obligatorios.","this_event_can_not_be_deleted":"Este evento no se puede eliminar","thu":"Jue","to":"Hasta","too_long":"Demasiado largo","too_short":"Demasiado corto","tue":"Mar","user_details":"Usuario","wed":"Mi\u00e9","yes":"S\u00ed"},"fr.js":{"add_location":"Ajouter un lieu","admin":"Administrateur","apply":"Appliquer","apr":"Avr","aug":"Ao\u00fbt","cancel":"Annuler","cancel_reason_cannot_space":"Le motif d'annulation ne peut pas \u00eatre constitu\u00e9 uniquement d'espaces.","cancel_reason_required":"Le champ Motif de l\u2019annulation est obligatoire.","cancel_scheduled":"Fen\u00eatre contextuelle Annuler les \u00e9v\u00e9nements programm\u00e9s","captcha_key":"Le champ cl\u00e9 Google Captcha est obligatoire.","captcha_secret":"Le champ cl\u00e9 Google Captcha est obligatoire.","choose_plan":"Choisissez un plan","contact_number_is_invalid_number":"Le num\u00e9ro de contact est un num\u00e9ro invalide","copied":"Copi\u00e9","copy_link":"Copier le lien","currency":"Devise","dec":"D\u00e9c","default_schedule":"L'horaire par d\u00e9faut ne peut pas \u00eatre mis \u00e0 jour.","delete":"Supprimer !","description":"La description","description_required":"La description est requise.","desig_required":"Le champ de la d\u00e9signation est requis.","email_verified_successfully":"E-mail v\u00e9rifi\u00e9 avec succ\u00e8s.","enquiry":"Enqu\u00eate","enter_google_api":"Veuillez entrer la cl\u00e9 API de l'endroit Google.","enter_valid_facebook_url":"Veuillez saisir une URL Facebook valide","enter_valid_instagram_url":"Veuillez saisir une URL Instagram valide","enter_valid_twitter_url":"Veuillez saisir une URL Twitter valide","event":"\u00c9v\u00e9nement","faq":"FAQ","feb":"F\u00e9v","fri":"Ven","from":"De","front_band":"Marque avant","front_testimonial":"T\u00e9moignage avant","invalid_country_code":"Code de pays invalide","invalid_number":"Num\u00e9ro invalide","jan":"Janv","jul":"Juil","jun":"Juin","linked_copy_successfully":"Lien copi\u00e9 avec succ\u00e8s.","location":"Le champ du nom de l'emplacement est requis.","location_white":"Le champ du nom de l'emplacement est requis.","mar":"Mar","mon":"Lun","name_required":"Le champ du nom est requis.","no":"Non","nov":"Nov","oct":"Oct","ok":"D'accord","paypal_client":"Veuillez entrer l'identifiant client Paypal.","paypal_mode":"Veuillez entrer le mode Paypal.","paypal_secret":"Veuillez entrer le secret Paypal.","paystack_key":"Veuillez saisir la cl\u00e9 Paystack.","paystack_secret":"Veuillez saisir Paystack Secret.","personal_experience":"Exp\u00e9rience personnelle","phone":"Le champ du num\u00e9ro de t\u00e9l\u00e9phone est requis.","phone_required":"Le champ du num\u00e9ro de t\u00e9l\u00e9phone est requis.","privacy_policy":"La politique de confidentialit\u00e9 est requise.","profile_size":"La taille du profil doit \u00eatre inf\u00e9rieure \u00e0 2 Mo.","razorpay_key":"Veuillez entrer votre cl\u00e9 RazorPay","razorpay_secret":"Veuillez entrer votre secret RazorPay","sat":"Sam","schedule":"Calendrier","schedule_name":"Le champ du nom de l'horaire est requis.","select_calender":"Veuillez s\u00e9lectionner un calendrier.","select_event_type":"S\u00e9lectionner le type d'\u00e9v\u00e9nement","select_personal_experience":"S\u00e9lectionner une exp\u00e9rience personnelle","select_status":"S\u00e9lectionner l'\u00e9tat","select_subscription_plans":"Choisissez les formules d'abonnement","sep":"Sep","short_description":"Le champ de la courte description est requis.","slot_time":"Le champ de l'heure de la plage horaire est requis.","something_went_wrong":"Quelque chose s'est mal pass\u00e9 !","stripe_key":"Veuillez entrer la cl\u00e9 Stripe.","stripe_secret":"Veuillez entrer le secret Stripe.","subscriber":"Abonn\u00e9","subscription_plan":"Plan d'abonnement","subscription_plans":"Plans d'abonnement","successful":"R\u00e9ussi","sun":"Dim","sure_delete":"\u00cates-vous s\u00fbr de vouloir supprimer ceci","terms_cond":"Termes et conditions","terms_condition":"Les termes et conditions sont requis.","this_event_can_not_be_deleted":"Cet \u00e9v\u00e9nement ne peut pas \u00eatre supprim\u00e9","thu":"Jeu","to":"\u00c0","too_long":"Trop long","too_short":"Trop court","tue":"Mar","user_details":"Utilisateur","wed":"Mer","yes":"Oui"},"pt.js":{"add_location":"Adicionar Local","admin":"Administrador","apply":"Aplicar","apr":"Abr","aug":"Ago","cancel":"Cancelar","cancel_reason_cannot_space":"O motivo do cancelamento n\u00e3o pode ser apenas espa\u00e7os.","cancel_reason_required":"O campo motivo do cancelamento \u00e9 obrigat\u00f3rio.","cancel_scheduled":"Pop-up Cancelar eventos agendados","captcha_key":"O campo-chave do Google Captcha \u00e9 obrigat\u00f3rio.","captcha_secret":"O campo Google Captcha Secret \u00e9 obrigat\u00f3rio.","choose_plan":"Escolha o Plano","contact_number_is_invalid_number":"O n\u00famero de contato \u00e9 um n\u00famero inv\u00e1lido","copied":"Copiado","copy_link":"Copiar Link","currency":"Moeda","dec":"Dez","default_schedule":"O cronograma padr\u00e3o n\u00e3o pode ser atualizado.","delete":"Excluir !","description":"Descri\u00e7\u00e3o","description_required":"A descri\u00e7\u00e3o \u00e9 obrigat\u00f3ria.","desig_required":"O campo de designa\u00e7\u00e3o \u00e9 obrigat\u00f3rio.","email_verified_successfully":"E-mail Verificado com Sucesso.","enquiry":"Inqu\u00e9rito","enter_google_api":"Por favor, insira a chave da API do Google Place.","enter_valid_facebook_url":"Por favor, insira um URL v\u00e1lido do Facebook","enter_valid_instagram_url":"Por favor, insira um URL v\u00e1lido do Instagram","enter_valid_twitter_url":"Por favor, insira um URL v\u00e1lido do Twitter","event":"Evento","faq":"FAQ","feb":"Fev","fri":"Sex","from":"De","front_band":"Marca Frontal","front_testimonial":"Depoimento Frontal","invalid_country_code":"C\u00f3digo de Pa\u00eds Inv\u00e1lido","invalid_number":"N\u00famero Inv\u00e1lido","jan":"Jan","jul":"Jul","jun":"Jun","linked_copy_successfully":"Link Copiado com Sucesso.","location":"O campo de nome do local \u00e9 obrigat\u00f3rio.","location_white":"O campo de nome do local \u00e9 obrigat\u00f3rio.","mar":"Mar","mon":"Seg","name_required":"O campo de nome \u00e9 obrigat\u00f3rio.","no":"N\u00e3o","nov":"Nov","oct":"Out","ok":"Ok","paypal_client":"Por favor, insira o ID do Cliente do Paypal.","paypal_mode":"Por favor, insira o Modo do Paypal.","paypal_secret":"Por favor, insira o Segredo do Paypal.","paystack_key":"Insira a chave da pilha de pagamento.","paystack_secret":"Por favor, insira o segredo da pilha de pagamento.","personal_experience":"Experi\u00eancia Pessoal","phone":"O campo de telefone \u00e9 obrigat\u00f3rio.","phone_required":"O campo de n\u00famero de telefone \u00e9 obrigat\u00f3rio.","privacy_policy":"A Pol\u00edtica de Privacidade \u00e9 obrigat\u00f3ria.","profile_size":"O tamanho do perfil deve ser inferior a 2 MB.","razorpay_key":"Por favor, insira sua chave RazorPay","razorpay_secret":"Por favor, insira seu segredo do RazorPay","sat":"S\u00e1b","schedule":"Cronograma","schedule_name":"O campo de nome do cronograma \u00e9 obrigat\u00f3rio.","select_calender":"Por favor, selecione um calend\u00e1rio.","select_event_type":"Selecione o Tipo de Evento","select_personal_experience":"Selecione a Experi\u00eancia Pessoal","select_status":"Selecione o Status","select_subscription_plans":"Escolha planos de assinatura","sep":"Set","short_description":"O campo de descri\u00e7\u00e3o curta \u00e9 obrigat\u00f3rio.","slot_time":"O campo de hor\u00e1rio do slot \u00e9 obrigat\u00f3rio.","something_went_wrong":"Algo deu errado!","stripe_key":"Por favor, insira a Chave do Stripe.","stripe_secret":"Por favor, insira o Segredo do Stripe.","subscriber":"Assinante","subscription_plan":"Plano de Assinatura","subscription_plans":"Planos de assinatura","successful":"Bem-sucedido","sun":"Dom","sure_delete":"Tem certeza de que deseja excluir isso","terms_cond":"Termos e Condi\u00e7\u00f5es","terms_condition":"Os Termos e Condi\u00e7\u00f5es s\u00e3o obrigat\u00f3rios.","this_event_can_not_be_deleted":"Este evento n\u00e3o pode ser exclu\u00eddo","thu":"Qui","to":"Para","too_long":"Muito Longo","too_short":"Muito Curto","tue":"Ter","user_details":"Usu\u00e1rio","wed":"Qua","yes":"Sim"},"ru.js":{"add_location":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043c\u0435\u0441\u0442\u043e\u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u0435","admin":"\u0410\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440","apply":"\u041f\u0440\u0438\u043c\u0435\u043d\u0438\u0442\u044c","apr":"\u0410\u043f\u0440","aug":"\u0410\u0432\u0433","cancel":"\u041e\u0442\u043c\u0435\u043d\u0430","cancel_reason_cannot_space":"\u041f\u0440\u0438\u0447\u0438\u043d\u043e\u0439 \u043e\u0442\u043c\u0435\u043d\u044b \u043d\u0435 \u043c\u043e\u0433\u0443\u0442 \u0431\u044b\u0442\u044c \u0442\u043e\u043b\u044c\u043a\u043e \u043f\u0440\u043e\u0431\u0435\u043b\u044b.","cancel_reason_required":"\u041f\u043e\u043b\u0435 \u043f\u0440\u0438\u0447\u0438\u043d\u044b \u043e\u0442\u043c\u0435\u043d\u044b \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e.","cancel_scheduled":"\u0412\u0441\u043f\u043b\u044b\u0432\u0430\u044e\u0449\u0435\u0435 \u043e\u043a\u043d\u043e \u00ab\u041e\u0442\u043c\u0435\u043d\u0438\u0442\u044c \u0437\u0430\u043f\u043b\u0430\u043d\u0438\u0440\u043e\u0432\u0430\u043d\u043d\u044b\u0435 \u043c\u0435\u0440\u043e\u043f\u0440\u0438\u044f\u0442\u0438\u044f\u00bb","captcha_key":"\u041f\u043e\u043b\u0435 \u043a\u043b\u044e\u0447\u0430 Google Captcha \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u044b\u043c.","captcha_secret":"\u041f\u043e\u043b\u0435 \u00ab\u0421\u0435\u043a\u0440\u0435\u0442 Google Captcha\u00bb \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u044b\u043c.","choose_plan":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u043b\u0430\u043d","contact_number_is_invalid_number":"\u041d\u043e\u043c\u0435\u0440 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430 - \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 \u043d\u043e\u043c\u0435\u0440","copied":"\u0421\u043a\u043e\u043f\u0438\u0440\u043e\u0432\u0430\u043d\u043e","copy_link":"\u0421\u043a\u043e\u043f\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u0441\u044b\u043b\u043a\u0443","currency":"\u0412\u0430\u043b\u044e\u0442\u0430","dec":"\u0414\u0435\u043a","default_schedule":"\u041d\u0435\u043b\u044c\u0437\u044f \u043e\u0431\u043d\u043e\u0432\u0438\u0442\u044c \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u043e\u0435 \u0440\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0435.","delete":"\u0423\u0434\u0430\u043b\u0438\u0442\u044c !","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","description_required":"\u0422\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u043e\u043f\u0438\u0441\u0430\u043d\u0438\u0435.","desig_required":"\u0422\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u043f\u043e\u043b\u0435 \u0441 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u0435\u043c.","email_verified_successfully":"Email \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d.","enquiry":"\u0417\u0430\u043f\u0440\u043e\u0441","enter_google_api":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u043a\u043b\u044e\u0447 API \u0434\u043b\u044f Google Place.","enter_valid_facebook_url":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 URL Facebook","enter_valid_instagram_url":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 URL Instagram","enter_valid_twitter_url":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 URL Twitter","event":"\u0421\u043e\u0431\u044b\u0442\u0438\u0435","faq":"\u0427\u0430\u0441\u0442\u043e \u0437\u0430\u0434\u0430\u0432\u0430\u0435\u043c\u044b\u0435 \u0432\u043e\u043f\u0440\u043e\u0441\u044b","feb":"\u0424\u0435\u0432","fri":"\u041f\u0442","from":"\u041e\u0442","front_band":"\u0424\u0440\u043e\u043d\u0442 \u0411\u0440\u0435\u043d\u0434","front_testimonial":"\u0422\u0435\u0441\u0442\u0438\u043c\u043e\u043d\u0438\u0430\u043b \u0444\u0440\u043e\u043d\u0442\u0430","invalid_country_code":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u043a\u043e\u0434 \u0441\u0442\u0440\u0430\u043d\u044b","invalid_number":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u043d\u043e\u043c\u0435\u0440","jan":"\u042f\u043d\u0432","jul":"\u0418\u044e\u043b\u044c","jun":"\u0418\u044e\u043d\u044c","linked_copy_successfully":"\u0421\u0432\u044f\u0437\u0430\u043d\u043e \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043a\u043e\u043f\u0438\u0440\u043e\u0432\u0430\u043d\u043e.","location":"\u041f\u043e\u043b\u0435 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u044f \u043c\u0435\u0441\u0442\u043e\u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f.","location_white":"\u041f\u043e\u043b\u0435 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u044f \u043c\u0435\u0441\u0442\u043e\u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f.","mar":"\u041c\u0430\u0440","mon":"\u041f\u043d","name_required":"\u0422\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u043f\u043e\u043b\u0435 \u0441 \u0438\u043c\u0435\u043d\u0435\u043c.","no":"\u041d\u0435\u0442","nov":"\u041d\u043e\u044f","oct":"\u041e\u043a\u0442","ok":"\u041e\u043a","paypal_client":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0438\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440 \u043a\u043b\u0438\u0435\u043d\u0442\u0430 Paypal.","paypal_mode":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0440\u0435\u0436\u0438\u043c Paypal.","paypal_secret":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u0435\u043a\u0440\u0435\u0442 Paypal.","paystack_key":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u043a\u043b\u044e\u0447 Paystack.","paystack_secret":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u0435\u043a\u0440\u0435\u0442 Paystack.","personal_experience":"\u041b\u0438\u0447\u043d\u044b\u0439 \u043e\u043f\u044b\u0442","phone":"\u041f\u043e\u043b\u0435 \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430 \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f.","phone_required":"\u041f\u043e\u043b\u0435 \u043d\u043e\u043c\u0435\u0440\u0430 \u0442\u0435\u043b\u0435\u0444\u043e\u043d\u0430 \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f.","privacy_policy":"\u0422\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u043f\u043e\u043b\u0438\u0442\u0438\u043a\u0430 \u043a\u043e\u043d\u0444\u0438\u0434\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u043e\u0441\u0442\u0438.","profile_size":"\u0420\u0430\u0437\u043c\u0435\u0440 \u043f\u0440\u043e\u0444\u0438\u043b\u044f \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u0435\u0435 2 \u041c\u0411.","razorpay_key":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u0432\u043e\u0439 \u043a\u043b\u044e\u0447 RazorPay","razorpay_secret":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u0432\u043e\u0439 \u0441\u0435\u043a\u0440\u0435\u0442 RazorPay","sat":"\u0421\u0431","schedule":"\u0420\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u0435","schedule_name":"\u041f\u043e\u043b\u0435 \u043d\u0430\u0437\u0432\u0430\u043d\u0438\u044f \u0440\u0430\u0441\u043f\u0438\u0441\u0430\u043d\u0438\u044f \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f.","select_calender":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c.","select_event_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u0441\u043e\u0431\u044b\u0442\u0438\u044f","select_personal_experience":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043b\u0438\u0447\u043d\u044b\u0439 \u043e\u043f\u044b\u0442","select_status":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0441\u0442\u0430\u0442\u0443\u0441","select_subscription_plans":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u043b\u0430\u043d\u044b \u043f\u043e\u0434\u043f\u0438\u0441\u043a\u0438","sep":"\u0421\u0435\u043d","short_description":"\u0422\u0440\u0435\u0431\u0443\u0435\u0442\u0441\u044f \u043a\u0440\u0430\u0442\u043a\u043e\u0435 \u043e\u043f\u0438\u0441\u0430\u043d\u0438\u0435.","slot_time":"\u041f\u043e\u043b\u0435 \u0432\u0440\u0435\u043c\u0435\u043d\u0438 \u0441\u043b\u043e\u0442\u0430 \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e \u0434\u043b\u044f \u0437\u0430\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f.","something_went_wrong":"\u0427\u0442\u043e-\u0442\u043e \u043f\u043e\u0448\u043b\u043e \u043d\u0435 \u0442\u0430\u043a!","stripe_key":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u043a\u043b\u044e\u0447 Stripe.","stripe_secret":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u0435\u043a\u0440\u0435\u0442 Stripe.","subscriber":"\u041f\u043e\u0434\u043f\u0438\u0441\u0447\u0438\u043a","subscription_plan":"\u041f\u043b\u0430\u043d \u043f\u043e\u0434\u043f\u0438\u0441\u043a\u0438","subscription_plans":"\u041f\u043b\u0430\u043d\u044b \u043f\u043e\u0434\u043f\u0438\u0441\u043a\u0438","successful":"\u0423\u0441\u043f\u0435\u0448\u043d\u043e","sun":"\u0412\u0441","sure_delete":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e","terms_cond":"\u0423\u0441\u043b\u043e\u0432\u0438\u044f \u0438 \u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f","terms_condition":"\u0422\u0440\u0435\u0431\u0443\u044e\u0442\u0441\u044f \u0443\u0441\u043b\u043e\u0432\u0438\u044f \u0438 \u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f.","this_event_can_not_be_deleted":"\u042d\u0442\u043e \u0441\u043e\u0431\u044b\u0442\u0438\u0435 \u043d\u0435\u043b\u044c\u0437\u044f \u0443\u0434\u0430\u043b\u0438\u0442\u044c","thu":"\u0427\u0442","to":"\u0414\u043e","too_long":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u0434\u043b\u0438\u043d\u043d\u043e\u0435","too_short":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u043a\u043e\u0440\u043e\u0442\u043a\u043e\u0435","tue":"\u0412\u0442","user_details":"\u041f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044c","wed":"\u0421\u0440","yes":"\u0414\u0430"},"tr.js":{"add_location":"Konum Ekle","admin":"Y\u00f6netici","apply":"Uygula","apr":"Nis","aug":"A\u011fu","cancel":"\u0130ptal","cancel_reason_cannot_space":"\u0130ptal nedeni yaln\u0131zca bo\u015fluk olamaz.","cancel_reason_required":"\u0130ptal nedeni alan\u0131 zorunludur.","cancel_scheduled":"Planlanm\u0131\u015f Etkinlikleri \u0130ptal Et a\u00e7\u0131l\u0131r penceresi","captcha_key":"Google Captcha anahtar\u0131 alan\u0131 gereklidir.","captcha_secret":"Google Captcha Gizli alan\u0131 zorunludur.","choose_plan":"Plan\u0131 Se\u00e7","contact_number_is_invalid_number":"\u0130leti\u015fim numaras\u0131 ge\u00e7ersiz numara","copied":"Kopyaland\u0131","copy_link":"Ba\u011flant\u0131y\u0131 Kopyala","currency":"Para Birimi","dec":"Ara","default_schedule":"Varsay\u0131lan program g\u00fcncellenemez.","delete":"Sil !","description":"A\u00e7\u0131klama","description_required":"A\u00e7\u0131klama alan\u0131 zorunludur.","desig_required":"Unvan alan\u0131 zorunludur.","email_verified_successfully":"E-posta Ba\u015far\u0131yla Do\u011fruland\u0131.","enquiry":"Sorgu","enter_google_api":"L\u00fctfen google place API anahtar\u0131 girin.","enter_valid_facebook_url":"L\u00fctfen ge\u00e7erli bir Facebook URL'si girin","enter_valid_instagram_url":"L\u00fctfen ge\u00e7erli bir Instagram URL'si girin","enter_valid_twitter_url":"L\u00fctfen ge\u00e7erli bir Twitter URL'si girin","event":"Etkinlik","faq":"SSS","feb":"\u015eub","fri":"Cum","from":"Kimden","front_band":"\u00d6n Marka","front_testimonial":"\u00d6n \u0130nceleme","invalid_country_code":"Ge\u00e7ersiz \u00fclke kodu","invalid_number":"Ge\u00e7ersiz Numara","jan":"Oca","jul":"Tem","jun":"Haz","linked_copy_successfully":"Ba\u011flant\u0131l\u0131 Ba\u015far\u0131yla Kopyaland\u0131.","location":"Konum ad\u0131 alan\u0131 zorunludur.","location_white":"Konum ad\u0131 alan\u0131 zorunludur.","mar":"Mar","mon":"Pzt","name_required":"Ad alan\u0131 zorunludur.","no":"Hay\u0131r","nov":"Kas","oct":"Eki","ok":"Tamam","paypal_client":"L\u00fctfen Paypal M\u00fc\u015fteri Kimli\u011fi girin.","paypal_mode":"L\u00fctfen Paypal Modu girin.","paypal_secret":"L\u00fctfen Paypal S\u0131rr\u0131 girin.","paystack_key":"L\u00fctfen Paystack Anahtar\u0131n\u0131 girin.","paystack_secret":"L\u00fctfen Paystack S\u0131rr\u0131n\u0131 girin.","personal_experience":"Ki\u015fisel Deneyim","phone":"Telefon alan\u0131 zorunludur.","phone_required":"Telefon numaras\u0131 alan\u0131 zorunludur.","privacy_policy":"Gizlilik Politikas\u0131 zorunludur.","profile_size":"Profil boyutu 2 MB'den k\u00fc\u00e7\u00fck olmal\u0131d\u0131r.","razorpay_key":"L\u00fctfen RazorPay anahtar\u0131n\u0131z\u0131 girin","razorpay_secret":"L\u00fctfen RazorPay S\u0131rr\u0131n\u0131z\u0131 girin","sat":"Cmt","schedule":"Program","schedule_name":"Program ad\u0131 alan\u0131 zorunludur.","select_calender":"L\u00fctfen bir takvim se\u00e7in.","select_event_type":"Etkinlik T\u00fcr\u00fcn\u00fc Se\u00e7","select_personal_experience":"Ki\u015fisel Deneyimi Se\u00e7","select_status":"Durumu Se\u00e7","select_subscription_plans":"Abonelik planlar\u0131n\u0131 se\u00e7in","sep":"Eyl","short_description":"K\u0131sa a\u00e7\u0131klama alan\u0131 zorunludur.","slot_time":"Yer zaman\u0131 alan\u0131 zorunludur.","something_went_wrong":"Bir \u015feyler yanl\u0131\u015f gitti!","stripe_key":"L\u00fctfen Stripe Anahtar\u0131 girin.","stripe_secret":"L\u00fctfen Stripe S\u0131rr\u0131 girin.","subscriber":"Abone","subscription_plan":"Abonelik Plan\u0131","subscription_plans":"Abonelik Planlar\u0131","successful":"Ba\u015far\u0131l\u0131","sun":"Paz","sure_delete":"Bu \u00f6\u011feyi silmek istedi\u011finizden emin misiniz","terms_cond":"Kullan\u0131m \u015eartlar\u0131","terms_condition":"Kullan\u0131m \u015eartlar\u0131 zorunludur.","this_event_can_not_be_deleted":"Bu etkinlik silinemez","thu":"Per","to":"Kime","too_long":"\u00c7ok uzun","too_short":"\u00c7ok k\u0131sa","tue":"Sal","user_details":"Kullan\u0131c\u0131","wed":"\u00c7ar","yes":"Evet"},"zh.js":{"add_location":"\u6dfb\u52a0\u4f4d\u7f6e","admin":"\u7ba1\u7406\u5458","apply":"\u7533\u8bf7","apr":"\u56db\u6708","aug":"\u516b\u6708","cancel":"\u53d6\u6d88","cancel_reason_cannot_space":"\u53d6\u6d88\u539f\u56e0\u4e0d\u80fd\u53ea\u662f\u7a7a\u683c\u3002","cancel_reason_required":"\u53d6\u6d88\u539f\u56e0\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","cancel_scheduled":"\u53d6\u6d88\u5df2\u5b89\u6392\u7684\u6d3b\u52a8\u5f39\u51fa\u7a97\u53e3","captcha_key":"Google \u9a8c\u8bc1\u7801\u5173\u952e\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","captcha_secret":"Google Captcha Secret \u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","choose_plan":"\u9009\u62e9\u8ba1\u5212","contact_number_is_invalid_number":"\u8054\u7cfb\u53f7\u7801\u662f\u65e0\u6548\u53f7\u7801","copied":"\u5df2\u590d\u5236","copy_link":"\u590d\u5236\u94fe\u63a5","currency":"\u8d27\u5e01","dec":"\u5341\u4e8c\u6708","default_schedule":"\u9ed8\u8ba4\u65e5\u7a0b\u4e0d\u80fd\u66f4\u65b0\u3002","delete":"\u5220\u9664\uff01","description":"\u63cf\u8ff0","description_required":"\u63cf\u8ff0\u662f\u5fc5\u9700\u7684\u3002","desig_required":"\u804c\u4f4d\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","email_verified_successfully":"\u7535\u5b50\u90ae\u4ef6\u9a8c\u8bc1\u6210\u529f\u3002","enquiry":"\u8be2\u95ee","enter_google_api":"\u8bf7\u8f93\u5165Google\u5730\u65b9API\u5bc6\u94a5\u3002","enter_valid_facebook_url":"\u8bf7\u8f93\u5165\u6709\u6548\u7684Facebook\u7f51\u5740","enter_valid_instagram_url":"\u8bf7\u8f93\u5165\u6709\u6548\u7684Instagram\u7f51\u5740","enter_valid_twitter_url":"\u8bf7\u8f93\u5165\u6709\u6548\u7684Twitter\u7f51\u5740","event":"\u4e8b\u4ef6","faq":"\u5e38\u89c1\u95ee\u9898","feb":"\u4e8c\u6708","fri":"\u661f\u671f\u4e94","from":"\u4ece","front_band":"\u524d\u7aef\u54c1\u724c","front_testimonial":"\u524d\u7aef\u63a8\u8350","invalid_country_code":"\u65e0\u6548\u7684\u56fd\u5bb6\u4ee3\u7801","invalid_number":"\u65e0\u6548\u53f7\u7801","jan":"\u4e00\u6708","jul":"\u4e03\u6708","jun":"\u516d\u6708","linked_copy_successfully":"\u94fe\u63a5\u5df2\u6210\u529f\u590d\u5236\u3002","location":"\u4f4d\u7f6e\u540d\u79f0\u5b57\u6bb5\u662f\u5fc5\u586b\u7684\u3002","location_white":"\u4f4d\u7f6e\u540d\u79f0\u5b57\u6bb5\u662f\u5fc5\u586b\u7684\u3002","mar":"\u4e09\u6708","mon":"\u661f\u671f\u4e00","name_required":"\u59d3\u540d\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","no":"\u5426","nov":"\u5341\u4e00\u6708","oct":"\u5341\u6708","ok":"\u597d\u7684","paypal_client":"\u8bf7\u8f93\u5165Paypal\u5ba2\u6237\u7aefID\u3002","paypal_mode":"\u8bf7\u8f93\u5165Paypal\u6a21\u5f0f\u3002","paypal_secret":"\u8bf7\u8f93\u5165Paypal\u79d8\u5bc6\u3002","paystack_key":"\u8bf7\u8f93\u5165 Paystack \u5bc6\u94a5\u3002","paystack_secret":"\u8bf7\u8f93\u5165 Paystack \u79d8\u5bc6\u3002","personal_experience":"\u4e2a\u4eba\u7ecf\u9a8c","phone":"\u7535\u8bdd\u5b57\u6bb5\u662f\u5fc5\u586b\u7684\u3002","phone_required":"\u624b\u673a\u53f7\u5b57\u6bb5\u662f\u5fc5\u586b\u7684\u3002","privacy_policy":"\u9690\u79c1\u653f\u7b56\u662f\u5fc5\u9700\u7684\u3002","profile_size":"\u914d\u7f6e\u6587\u4ef6\u5927\u5c0f\u5e94\u5c0f\u4e8e2 MB\u3002","razorpay_key":"\u8bf7\u8f93\u5165\u60a8\u7684 RazorPay \u5bc6\u94a5","razorpay_secret":"\u8bf7\u8f93\u5165\u60a8\u7684 RazorPay \u5bc6\u7801","sat":"\u661f\u671f\u516d","schedule":"\u65e5\u7a0b","schedule_name":"\u65e5\u7a0b\u540d\u79f0\u5b57\u6bb5\u662f\u5fc5\u586b\u7684\u3002","select_calender":"\u8bf7\u9009\u62e9\u65e5\u5386\u3002","select_event_type":"\u9009\u62e9\u4e8b\u4ef6\u7c7b\u578b","select_personal_experience":"\u9009\u62e9\u4e2a\u4eba\u7ecf\u9a8c","select_status":"\u9009\u62e9\u72b6\u6001","select_subscription_plans":"\u9078\u64c7\u8a02\u95b1\u8a08\u5283","sep":"\u4e5d\u6708","short_description":"\u77ed\u63cf\u8ff0\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","slot_time":"\u65f6\u9699\u65f6\u95f4\u5b57\u6bb5\u662f\u5fc5\u586b\u7684\u3002","something_went_wrong":"\u51fa\u4e86\u4e9b\u95ee\u9898\uff01","stripe_key":"\u8bf7\u8f93\u5165Stripe\u5bc6\u94a5\u3002","stripe_secret":"\u8bf7\u8f93\u5165Stripe\u79d8\u5bc6\u3002","subscriber":"\u8ba2\u9605\u8005","subscription_plan":"\u8ba2\u9605\u8ba1\u5212","subscription_plans":"\u8a02\u95b1\u8a08\u5283","successful":"\u6210\u529f","sun":"\u661f\u671f\u65e5","sure_delete":"\u60a8\u786e\u5b9a\u8981\u5220\u9664\u8fd9\u4e2a\u5417","terms_cond":"\u6761\u6b3e\u4e0e\u6761\u4ef6","terms_condition":"\u6761\u6b3e\u4e0e\u6761\u4ef6\u662f\u5fc5\u9700\u7684\u3002","this_event_can_not_be_deleted":"\u65e0\u6cd5\u5220\u9664\u6b64\u4e8b\u4ef6","thu":"\u661f\u671f\u56db","to":"\u5230","too_long":"\u592a\u957f","too_short":"\u592a\u77ed","tue":"\u661f\u671f\u4e8c","user_details":"\u7528\u6237","wed":"\u661f\u671f\u4e09","yes":"\u662f"}});
})();
